@@ -85,7 +85,7 @@ class Globals:
     TOKEN_PIP_USER = '__TOKEN_PIP_USER__'
     KW_SPACE_PIP_USER = f'{Constant.SPACE}--user'
     PIP_INSTALL = f'python -m pip install --upgrade{TOKEN_PIP_USER} --force-reinstall'
-    UPDATE_PIP_INSTALL = f'python -m pip install --upgrade {TOKEN_PIP_USER} pip'
+    UPDATE_PIP_INSTALL = f'python -m pip install --upgrade{TOKEN_PIP_USER} pip'
 
     CHARACTERE_FILTER = [
         '__'
@@ -120,9 +120,10 @@ class Globals:
 
     SAFE_AMOUNT_OF_TRIPLE_SINGLE_OR_DOUBLE_QUOTES_PLUS_ONE = 4
 
-    PYTHON_VERSION_PLACEHOLDER = '__PYTHON_VERSION_PLACEHOLDER__'
-    STATIC_DIRECTORY_PATH = f'{OS_SEPARATOR}lib{OS_SEPARATOR}python{PYTHON_VERSION_PLACEHOLDER}{OS_SEPARATOR}site-packages{OS_SEPARATOR}statics'
-    PYTHON_LANGUAGE_NAME = 'python'
+    LIB = 'lib'
+    STATIC_PACKAGE_PATH = f'{OS_SEPARATOR}statics'
+    TOKEN_PYTHON_VERSION = '__TOKEN_PYTHON_VERSION__'
+    HEROKU_PYTHON = f'{OS_SEPARATOR}lib{OS_SEPARATOR}python{TOKEN_PYTHON_VERSION}{OS_SEPARATOR}site-packages'
 
     DEBUG =     '[DEBUG  ] '
     ERROR =     '[ERROR  ] '
@@ -682,7 +683,7 @@ class Globals:
 
     def getStaticPackagePath(self) :
         staticPackageList = site.getsitepackages()
-        log.debug(getStaticPackagePath,f'Static packages list: {staticPackageList}. Picking the first one')
+        self.debug(f'Static packages list: {staticPackageList}. Picking the first one')
         staticPackage = str(staticPackageList[0])
         staticPackage = staticPackage.replace(f'{Globals.BACK_SLASH}{Globals.BACK_SLASH}',Globals.OS_SEPARATOR)
         staticPackage = staticPackage.replace(Globals.BACK_SLASH,Globals.OS_SEPARATOR)
@@ -690,9 +691,11 @@ class Globals:
         staticPackage = staticPackage.replace(Globals.SLASH,Globals.OS_SEPARATOR)
         if staticPackage[-1] == str(Globals.OS_SEPARATOR) :
             staticPackage = staticPackage[:-1]
-        pythonVersion = Globals.STATIC_DIRECTORY_PATH.replace(Globals.PYTHON_VERSION_PLACEHOLDER, str(self.getApiSetting(AttributeKey.PYTHON_VERSION)))
-        if not pythonVersion in staticPackage :
-            staticPackage = f'{staticPackage}{pythonVersion}'
+        pythonVersionWithoutDot = str(self.getApiSetting(AttributeKey.PYTHON_VERSION)).replace(Constant.DOT, Constant.NOTHING)
+        herokuPythonLibPath = Globals.HEROKU_PYTHON.replace(Globals.TOKEN_PYTHON_VERSION, pythonVersionWithoutDot)
+        if staticPackage.endswith(herokuPythonLibPath) :
+            staticPackage = staticPackage.replace(herokuPythonLibPath,Constant.NOTHING)
+        staticPackage = f'{staticPackage}{Globals.STATIC_PACKAGE_PATH}'
         self.debug(f'Static package: "{staticPackage}"')
         return staticPackage
 
@@ -753,21 +756,6 @@ class Globals:
                 classPortion = f'{classRequest.__name__} '
                 print(f'{Constant.SETTING}{classPortion}{message}')
 
-def getStaticPackagePath() :
-    staticPackageList = site.getsitepackages()
-    log.debug(getStaticPackagePath,f'Static packages list: {staticPackageList}. Picking the first one')
-    staticPackage = str(staticPackageList[0])
-    staticPackage = staticPackage.replace(f'{Globals.BACK_SLASH}{Globals.BACK_SLASH}',Globals.OS_SEPARATOR)
-    staticPackage = staticPackage.replace(Globals.BACK_SLASH,Globals.OS_SEPARATOR)
-    staticPackage = staticPackage.replace(f'{Globals.SLASH}{Globals.SLASH}',Globals.OS_SEPARATOR)
-    staticPackage = staticPackage.replace(Globals.SLASH,Globals.OS_SEPARATOR)
-    if staticPackage[-1] == str(Globals.OS_SEPARATOR) :
-        staticPackage = staticPackage[:-1]
-    staticPackage = f'{staticPackage}{Globals.STATIC_DIRECTORY_PATH}'
-    staticPackage = staticPackage.replace(Globals.PYTHON_VERSION_PLACEHOLDER, Constant.NOTHING)
-    log.debug(getStaticPackagePath,f'Static package: "{staticPackage}"')
-    return staticPackage
-
 def searchTreeList(search,tree) :
     def keepSearching(search,history,tree,treeList):
         if dict == type(tree) :
